var libeis_8h =
[
    [ "eis_clock_now_func", "group__libeis.html#ga467aad1271cd83e14056074f4652af89", null ],
    [ "eis_log_handler", "group__libeis-log.html#ga2377dec7bcdaaf05558c409af5f5e5f0", null ],
    [ "eis_device_capability", "group__libeis.html#ga1d4a2ad39b9a179c52881bbd20a12f78", [
      [ "EIS_DEVICE_CAP_POINTER", "group__libeis.html#gga1d4a2ad39b9a179c52881bbd20a12f78a578158934e345a296edc59502d7a7880", null ],
      [ "EIS_DEVICE_CAP_POINTER_ABSOLUTE", "group__libeis.html#gga1d4a2ad39b9a179c52881bbd20a12f78adcf722a2e3c66a1c9ffbdd093cfe734a", null ],
      [ "EIS_DEVICE_CAP_KEYBOARD", "group__libeis.html#gga1d4a2ad39b9a179c52881bbd20a12f78abe981b5fe1aedc97ca7032e9191f081b", null ],
      [ "EIS_DEVICE_CAP_TOUCH", "group__libeis.html#gga1d4a2ad39b9a179c52881bbd20a12f78a8e4039beead9797c5ec42fb24325abda", null ],
      [ "EIS_DEVICE_CAP_SCROLL", "group__libeis.html#gga1d4a2ad39b9a179c52881bbd20a12f78a6c4497dca657f40c9ec8bf1ccaa19801", null ],
      [ "EIS_DEVICE_CAP_BUTTON", "group__libeis.html#gga1d4a2ad39b9a179c52881bbd20a12f78ac526f3c673a2f501e7a8cd35bf81f240", null ]
    ] ],
    [ "eis_device_type", "group__libeis.html#ga124ae37c6def91c29224a82b8582b081", [
      [ "EIS_DEVICE_TYPE_VIRTUAL", "group__libeis.html#gga124ae37c6def91c29224a82b8582b081a4651e7ecd316f8023ae2d6bdbe565f10", null ],
      [ "EIS_DEVICE_TYPE_PHYSICAL", "group__libeis.html#gga124ae37c6def91c29224a82b8582b081acbe28720c804ceb8e5039886ff243d7e", null ]
    ] ],
    [ "eis_event_type", "group__libeis.html#ga3287e79a6ffcdb8f13573a6d4f9bfbbb", [
      [ "EIS_EVENT_CLIENT_CONNECT", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbabee1492ccc625fead30f3b5b32eba411", null ],
      [ "EIS_EVENT_CLIENT_DISCONNECT", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba308dd75e0c40d8b6773f9949ab2d1d83", null ],
      [ "EIS_EVENT_SEAT_BIND", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbade4f97145108c150e315a856b8471d1e", null ],
      [ "EIS_EVENT_DEVICE_CLOSED", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba5ccc8660e714bf693d21559aa08a20d9", null ],
      [ "EIS_EVENT_PONG", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba2f1c2b3770057880e0c55eb0b5d6807d", null ],
      [ "EIS_EVENT_SYNC", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba88592bed8435c8022d145320dd5aba60", null ],
      [ "EIS_EVENT_FRAME", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba951c1b8e54e7f19a866d8412da0b4f0d", null ],
      [ "EIS_EVENT_DEVICE_START_EMULATING", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba23f5a32ccab7d4f9543e546afd9e6b92", null ],
      [ "EIS_EVENT_DEVICE_STOP_EMULATING", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba9a756ac655536795c5e46931dc46e6f8", null ],
      [ "EIS_EVENT_POINTER_MOTION", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba751aa975226d9b88c569d89760aaf27f", null ],
      [ "EIS_EVENT_POINTER_MOTION_ABSOLUTE", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbae381d0f02997ad14ee933c10969c4ad0", null ],
      [ "EIS_EVENT_BUTTON_BUTTON", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba2b0f0c4650d19687dfd8581472a743f7", null ],
      [ "EIS_EVENT_SCROLL_DELTA", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbab2604d35504ec101d175bb9c47e617a0", null ],
      [ "EIS_EVENT_SCROLL_STOP", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba102e78da9b9d382f8277e9d94b509375", null ],
      [ "EIS_EVENT_SCROLL_CANCEL", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbab3c7a0143b39c1830ea7f1200bc04845", null ],
      [ "EIS_EVENT_SCROLL_DISCRETE", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbac52de8a8d9132633b32bdc931367be53", null ],
      [ "EIS_EVENT_KEYBOARD_KEY", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbac4f756e3a4df807312dea40efe26dfec", null ],
      [ "EIS_EVENT_TOUCH_DOWN", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba745cc5050895d88ad52942dc7d5477b0", null ],
      [ "EIS_EVENT_TOUCH_UP", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba0615ea1991919e9ee6e695c3aa388e51", null ],
      [ "EIS_EVENT_TOUCH_MOTION", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbab7584f727ae47efb4b11ce428687083f", null ]
    ] ],
    [ "eis_keymap_type", "group__libeis.html#ga3661c5282a62ca8de5eb2d1b5c3d4417", [
      [ "EIS_KEYMAP_TYPE_XKB", "group__libeis.html#gga3661c5282a62ca8de5eb2d1b5c3d4417a619e33783bf6ed3c301943972c0ffbc9", null ]
    ] ],
    [ "eis_log_priority", "group__libeis-log.html#ga3c47b589a2a911687cde738646bbdd4d", [
      [ "EIS_LOG_PRIORITY_DEBUG", "group__libeis-log.html#gga3c47b589a2a911687cde738646bbdd4dab5b8120b0d96f1405fe9bdd7cb374510", null ],
      [ "EIS_LOG_PRIORITY_INFO", "group__libeis-log.html#gga3c47b589a2a911687cde738646bbdd4da562ce27b874eee797352b74604b6082d", null ],
      [ "EIS_LOG_PRIORITY_WARNING", "group__libeis-log.html#gga3c47b589a2a911687cde738646bbdd4da58fc1c12e1d891bab4c527ed5033763f", null ],
      [ "EIS_LOG_PRIORITY_ERROR", "group__libeis-log.html#gga3c47b589a2a911687cde738646bbdd4da6af72273b759423967fd2cbe2682f8d0", null ]
    ] ],
    [ "eis_backend_fd_add_client", "group__libeis.html#ga04db8919a0169807b8faf0d951dd307f", null ],
    [ "eis_client_connect", "group__libeis.html#ga3f4dfb9f0eb7c0894180b4f1700ddd2e", null ],
    [ "eis_client_disconnect", "group__libeis.html#ga97204e4aab5a7bad87cbbbe3c6c72ff1", null ],
    [ "eis_client_get_context", "group__libeis.html#ga2939b1cdab00743bd1009c47d0381dc9", null ],
    [ "eis_client_get_name", "group__libeis.html#ga701de8148a117e3c330e7813661e15bc", null ],
    [ "eis_client_get_user_data", "group__libeis.html#ga89fbbabfbcd1990e651fd1fd70044edd", null ],
    [ "eis_client_is_sender", "group__libeis.html#ga3fe13b4dea5fa88fc05e397b88cc68fd", null ],
    [ "eis_client_new_ping", "group__libeis.html#ga3b35770369ad947ef5b1cd3fe4a735ba", null ],
    [ "eis_client_new_seat", "group__libeis.html#ga42dbc6a5cde697762fbf3f9520daff3f", null ],
    [ "eis_client_ref", "group__libeis.html#gadc8186e32b93c00204b7090f63fa756a", null ],
    [ "eis_client_set_user_data", "group__libeis.html#ga17b0cab07d25a8ac7b325fedc9420802", null ],
    [ "eis_client_unref", "group__libeis.html#gab22f6aa04204319cf02e4eb62f3b82ee", null ],
    [ "eis_clock_set_now_func", "group__libeis.html#ga6ffb1cb4f37483820467f4095780503a", null ],
    [ "eis_device_add", "group__libeis-device.html#gaf5d0f5d3a63961667d504beb9bf38ecc", null ],
    [ "eis_device_button_button", "group__libeis-receiver.html#gae086d855ec87817da9bcbbe2649b1d5d", null ],
    [ "eis_device_configure_capability", "group__libeis-device.html#gaa321cc6bf249bd586f9fbf7b14a854ea", null ],
    [ "eis_device_configure_name", "group__libeis-device.html#ga91d432a6b80ff7c41317b246cb7676d9", null ],
    [ "eis_device_configure_size", "group__libeis-device.html#ga3ef0ffc42f8a474db9eb3084004d7a54", null ],
    [ "eis_device_configure_type", "group__libeis-device.html#ga013407157b484b1bb16788a0e37b7ab9", null ],
    [ "eis_device_frame", "group__libeis-receiver.html#gaf6bd0508bf15480a3629ce9121dc698a", null ],
    [ "eis_device_get_client", "group__libeis-device.html#gaf680b4700fd9c9478dc362ea90e27c80", null ],
    [ "eis_device_get_context", "group__libeis-device.html#gaeb094ed73d2757f346df9df2a74b0f26", null ],
    [ "eis_device_get_height", "group__libeis-device.html#ga161f558060026c95ad7df2685d0aa94e", null ],
    [ "eis_device_get_name", "group__libeis-device.html#ga5447ebdb4b91c1f87d56cff5a3b3f915", null ],
    [ "eis_device_get_region", "group__libeis-device.html#gaec220f3da2b713eec452b4f6c46f767b", null ],
    [ "eis_device_get_region_at", "group__libeis-device.html#gadc75948ff63f63e9e9224c3a917c9ad5", null ],
    [ "eis_device_get_seat", "group__libeis-device.html#ga8e1f82ff82cbca6172b68f677c172217", null ],
    [ "eis_device_get_type", "group__libeis-device.html#ga95fb81f9a5d450ad82a2c18e042e64a6", null ],
    [ "eis_device_get_user_data", "group__libeis-device.html#ga4fab7fd651f88610765e35d84b6772a9", null ],
    [ "eis_device_get_width", "group__libeis-device.html#gae2971173b7e4356e4993f4c59756f4d8", null ],
    [ "eis_device_has_capability", "group__libeis-device.html#ga03cc58023643fafbf2cf85e4f01d35d2", null ],
    [ "eis_device_keyboard_get_keymap", "group__libeis-device.html#gad927b0cab6a09f50a9f08e999e5926f3", null ],
    [ "eis_device_keyboard_key", "group__libeis-receiver.html#gab7b5e74f1a73d076a67f2805e0cf5169", null ],
    [ "eis_device_keyboard_send_xkb_modifiers", "group__libeis-device.html#ga67e148a5527665ff88b88cb34f8e9ea0", null ],
    [ "eis_device_new_keymap", "group__libeis-device.html#ga2e784f05f57942dda1fd2c0741390b14", null ],
    [ "eis_device_new_region", "group__libeis-device.html#ga9f82f83ab0908a7cb0b716ce9644d8bf", null ],
    [ "eis_device_pause", "group__libeis-device.html#ga849c4b3033e43cd8b08957d1da3f0f01", null ],
    [ "eis_device_pointer_motion", "group__libeis-receiver.html#ga3825f9fae5fb97176a9e784b9b568d79", null ],
    [ "eis_device_pointer_motion_absolute", "group__libeis-receiver.html#ga2031f06ea76a8e53e117b59592c33eeb", null ],
    [ "eis_device_ref", "group__libeis-device.html#ga6a88f852f6e8eac09a0de06a8ce0c4f1", null ],
    [ "eis_device_remove", "group__libeis-device.html#ga140f3cc0e2d8e978515b4326a70eda3b", null ],
    [ "eis_device_resume", "group__libeis-device.html#ga51ec15f7874827f7d7472b64803015de", null ],
    [ "eis_device_scroll_cancel", "group__libeis-receiver.html#gafae8436a6a8e3e89787f68afabeff5b0", null ],
    [ "eis_device_scroll_delta", "group__libeis-receiver.html#ga8896fd0d9235d94e9c2b9942ea7aeaf2", null ],
    [ "eis_device_scroll_discrete", "group__libeis-receiver.html#gab8205ceaea638a911e7ee709afe542ba", null ],
    [ "eis_device_scroll_stop", "group__libeis-receiver.html#ga41f7229203a4ef7b6a6c160158160602", null ],
    [ "eis_device_set_user_data", "group__libeis-device.html#ga398884ecdb30abd271b6e2ba488d8079", null ],
    [ "eis_device_start_emulating", "group__libeis-receiver.html#ga7d51d406a1ed01119b1d027f196134f3", null ],
    [ "eis_device_stop_emulating", "group__libeis-receiver.html#gab3a994221f6e19300ebb7199541e5f53", null ],
    [ "eis_device_touch_new", "group__libeis-receiver.html#ga94b799954c66f990e99c686ecd52e597", null ],
    [ "eis_device_unref", "group__libeis-device.html#ga3b45805dd3f9951344fbcdb992178726", null ],
    [ "eis_dispatch", "group__libeis.html#gae9a84ebc406dca42172344a814938d67", null ],
    [ "eis_event_button_get_button", "group__libeis-sender.html#ga7b739998a4a7a3b9d27908bb0382ea99", null ],
    [ "eis_event_button_get_is_press", "group__libeis-sender.html#gadf9b03a1a7ac63cc34506889c62f20af", null ],
    [ "eis_event_emulating_get_sequence", "group__libeis-sender.html#gaf8edd83ddd292f42b5cf03e29d86d69b", null ],
    [ "eis_event_get_client", "group__libeis.html#gad7c70289c80fb5caddada588b82e8270", null ],
    [ "eis_event_get_device", "group__libeis.html#ga8ad0b321ee2fceabb5648d7bcf914659", null ],
    [ "eis_event_get_seat", "group__libeis.html#ga2222fc8d04e99f35c1246ee2bfe0ea0e", null ],
    [ "eis_event_get_time", "group__libeis.html#ga83d094e82723714444ed3f21a26e16c8", null ],
    [ "eis_event_get_type", "group__libeis.html#ga570a8f3d2e29147ce151d1658a4af949", null ],
    [ "eis_event_keyboard_get_key", "group__libeis-sender.html#ga2218709671a9f047f0af7b35514148b3", null ],
    [ "eis_event_keyboard_get_key_is_press", "group__libeis-sender.html#ga883df9c70a620193234bafcbd827b85d", null ],
    [ "eis_event_pointer_get_absolute_x", "group__libeis-sender.html#gadb97039d5ab2d90b6cf23f0ee2a16225", null ],
    [ "eis_event_pointer_get_absolute_y", "group__libeis-sender.html#gad7a06ae46dce11d2554325a258b5f56c", null ],
    [ "eis_event_pointer_get_dx", "group__libeis-sender.html#gaf6f044753909a90e6b95c9ea9bb6e81b", null ],
    [ "eis_event_pointer_get_dy", "group__libeis-sender.html#gac1e85d503bf4f36ea38775dd4ab0c7c2", null ],
    [ "eis_event_pong_get_ping", "group__libeis.html#ga5317a721145a0465c8ee5e3b8e819d5b", null ],
    [ "eis_event_scroll_get_discrete_dx", "group__libeis-sender.html#ga6aa0b54100ae86bbfa012416af073c7c", null ],
    [ "eis_event_scroll_get_discrete_dy", "group__libeis-sender.html#ga610cb0b302d816d630a676a161e9192a", null ],
    [ "eis_event_scroll_get_dx", "group__libeis-sender.html#ga6ac8482707400828fc7f3f4889efc1a1", null ],
    [ "eis_event_scroll_get_dy", "group__libeis-sender.html#ga676fcd1479e65737b0080ffcd9050ea0", null ],
    [ "eis_event_scroll_get_stop_x", "group__libeis-sender.html#ga847fbcfc6e4ab56ffb307bfb13c07384", null ],
    [ "eis_event_scroll_get_stop_y", "group__libeis-sender.html#gaaf9cfc77e7daf396b53609ecf344c428", null ],
    [ "eis_event_seat_has_capability", "group__libeis.html#gafa127cbddb71311193e07541b1f1c75d", null ],
    [ "eis_event_touch_get_id", "group__libeis-sender.html#ga3359817c6106c139d1e3ca487f1ece2a", null ],
    [ "eis_event_touch_get_is_cancel", "group__libeis-sender.html#ga98689c3df87a93b7f202e531365851e2", null ],
    [ "eis_event_touch_get_x", "group__libeis-sender.html#ga563f03da5ad0132f5c671a5f3485c20f", null ],
    [ "eis_event_touch_get_y", "group__libeis-sender.html#gab6ec3a3e2734c2bc2d98a3f31b0c1640", null ],
    [ "eis_event_type_to_string", "group__libeis.html#ga053398fc33056cde10d74e049662904d", null ],
    [ "eis_event_unref", "group__libeis.html#ga066e1b03f991dd920dede64de2f1bf59", null ],
    [ "eis_get_event", "group__libeis.html#ga8ab7102e6b177513a4b78098a36aaaae", null ],
    [ "eis_get_fd", "group__libeis.html#ga5e147e1917f6c0c2d179acdc6d4a04cd", null ],
    [ "eis_get_user_data", "group__libeis.html#gaebec91676c1fb89cbd6df33d101e77b0", null ],
    [ "eis_keymap_add", "group__libeis-keymap.html#gafcf34df68d068c55d52054b9b95ddc6e", null ],
    [ "eis_keymap_get_device", "group__libeis-keymap.html#gadcc5e8fc6becf78192fac72dd28bfdd3", null ],
    [ "eis_keymap_get_fd", "group__libeis-keymap.html#gacae73e975f480b79cf36566830319468", null ],
    [ "eis_keymap_get_size", "group__libeis-keymap.html#ga247e8a820690a839def28d50d1885be8", null ],
    [ "eis_keymap_get_type", "group__libeis-keymap.html#ga7c604e211af64a733369e53556d34cd5", null ],
    [ "eis_keymap_get_user_data", "group__libeis-keymap.html#ga475b6fa7772898d0afb52f131d992f1c", null ],
    [ "eis_keymap_ref", "group__libeis-keymap.html#ga986451c9617af0138e50a9fcb85507ef", null ],
    [ "eis_keymap_set_user_data", "group__libeis-keymap.html#gaeb3c1b0008dfe15e757e65744bfc5b9b", null ],
    [ "eis_keymap_unref", "group__libeis-keymap.html#ga101d493944acffab9bf25cbb7b89fe2b", null ],
    [ "eis_log_context_get_file", "group__libeis-log.html#gafdb5f48a1ddc2dd6eb16999059588d25", null ],
    [ "eis_log_context_get_func", "group__libeis-log.html#ga7ca095ef266bd7e71747f47b3f7278d9", null ],
    [ "eis_log_context_get_line", "group__libeis-log.html#gae0e3e1b3a1323ccd95397a6d3d9972c0", null ],
    [ "eis_log_get_priority", "group__libeis-log.html#gaf32da211cf2aab244acc0a3caa7bd67f", null ],
    [ "eis_log_set_handler", "group__libeis-log.html#ga588cd71aecd0c21f7d6c3fabc6c8b3f9", null ],
    [ "eis_log_set_priority", "group__libeis-log.html#ga8b8ba495b76ba6bc23dccbe18dac13c9", null ],
    [ "eis_new", "group__libeis.html#ga63fedbac98010b1cb1bd3e5337038061", null ],
    [ "eis_now", "group__libeis.html#gacf9d41645c32c494bc41e8034200e1ae", null ],
    [ "eis_peek_event", "group__libeis.html#ga963f72c1ca469415509d51e31b842379", null ],
    [ "eis_ping", "group__libeis.html#ga55fd8fc3ad8429c000bb68c8420de818", null ],
    [ "eis_ping_get_id", "group__libeis.html#gacda0204897e2cb8c39f2c8af78514b9e", null ],
    [ "eis_ping_get_user_data", "group__libeis.html#gad8ac37a051829a77cd682f6261b0eb63", null ],
    [ "eis_ping_ref", "group__libeis.html#gae16325662101b4c1ffb3ffaf48938c08", null ],
    [ "eis_ping_set_user_data", "group__libeis.html#ga6c969f629ca64cc38047d42d1f8a44b6", null ],
    [ "eis_ping_unref", "group__libeis.html#gac6cf11f783d3ee4149ee308279326a6f", null ],
    [ "eis_ref", "group__libeis.html#ga7660f7d3079be407553f2191fa34e53b", null ],
    [ "eis_region_add", "group__libeis-region.html#ga2a67457c09e363be9c55aad7680fac72", null ],
    [ "eis_region_contains", "group__libeis-region.html#ga7dd89ab7cd73229daa8484877d394ff9", null ],
    [ "eis_region_get_height", "group__libeis-region.html#ga76ec429698bb1ba0fc10f3e0ab46341d", null ],
    [ "eis_region_get_mapping_id", "group__libeis-region.html#gaa2ca0e28be403971ca693ffc7ffacb50", null ],
    [ "eis_region_get_physical_scale", "group__libeis-region.html#gae63a7e816af991ffd35eb2ce5ca48fcc", null ],
    [ "eis_region_get_user_data", "group__libeis-region.html#ga5ab5bf6c30df8ab30532131a0f4a85ed", null ],
    [ "eis_region_get_width", "group__libeis-region.html#ga94782bce1d632715fd6cf011f60e9a2d", null ],
    [ "eis_region_get_x", "group__libeis-region.html#gaab4c9380a2d5d5856aa43d8c769a6e2d", null ],
    [ "eis_region_get_y", "group__libeis-region.html#ga4b89edb43e67a20dabc0d08db00a3e3e", null ],
    [ "eis_region_ref", "group__libeis-region.html#gae833936863194105bc04e1c5fb34f083", null ],
    [ "eis_region_set_mapping_id", "group__libeis-region.html#gaa1ba28204da264855ffa500062e1ec3f", null ],
    [ "eis_region_set_offset", "group__libeis-region.html#ga2ef3ded3e873e3593ac6381d86767273", null ],
    [ "eis_region_set_physical_scale", "group__libeis-region.html#ga8b9860e8f4afbdecff2c7917740b8843", null ],
    [ "eis_region_set_size", "group__libeis-region.html#ga00f8da12a7dbc1cf8af6fd48886a521d", null ],
    [ "eis_region_set_user_data", "group__libeis-region.html#ga87b875de2e81bc281119d1d62acbcf7c", null ],
    [ "eis_region_unref", "group__libeis-region.html#ga02364f58ef5ccb70a1ffc2b8c119d712", null ],
    [ "eis_seat_add", "group__libeis-seat.html#ga5079e14572922d4ac0aeaf4c3e9a6e10", null ],
    [ "eis_seat_configure_capability", "group__libeis-seat.html#gaefb64c99967c5ac48814a151298ae90b", null ],
    [ "eis_seat_get_client", "group__libeis-seat.html#ga4eeece8f39d34d1ff35866f154ab8a91", null ],
    [ "eis_seat_get_context", "group__libeis-seat.html#ga6147b263a323b8b2c959f580802a178e", null ],
    [ "eis_seat_get_name", "group__libeis-seat.html#gac720535f4ecef3a06738c4646bcb55ca", null ],
    [ "eis_seat_get_user_data", "group__libeis-seat.html#gacb9f0484c624c65b2f24691660035ac4", null ],
    [ "eis_seat_has_capability", "group__libeis-seat.html#gae785d4dae9a2854f459482522309cece", null ],
    [ "eis_seat_new_device", "group__libeis-seat.html#gaa11265b128d2f54a7aeb5e1a5a77d818", null ],
    [ "eis_seat_ref", "group__libeis-seat.html#gaa929aa8d8e00728aef72c463bc0ca009", null ],
    [ "eis_seat_remove", "group__libeis-seat.html#ga430efc917a97c4080aef53b584b8fc26", null ],
    [ "eis_seat_set_user_data", "group__libeis-seat.html#gaf458b6f5497bb502e587f757639db67d", null ],
    [ "eis_seat_unref", "group__libeis-seat.html#ga41d8550739396facc5dd8d8b7cb8f3ec", null ],
    [ "eis_set_user_data", "group__libeis.html#ga90a8abf6e9433cb267781edc540fe405", null ],
    [ "eis_setup_backend_fd", "group__libeis.html#gade5cc09b2c6c2c7c90bf3f2b968cdb56", null ],
    [ "eis_setup_backend_socket", "group__libeis.html#gad615c678d89c16c124f299f08388da7c", null ],
    [ "eis_touch_cancel", "group__libeis-receiver.html#ga66eab021e4641e8c6fc13b2e8e2dd90a", null ],
    [ "eis_touch_down", "group__libeis-receiver.html#gab7679b3dd4bb18a5dd39a85ed259eb35", null ],
    [ "eis_touch_get_device", "group__libeis-receiver.html#gae691795024ff182b5d3066316f0c2c3b", null ],
    [ "eis_touch_get_user_data", "group__libeis-receiver.html#ga2d5636e19c2c850cd01fab1310b69ade", null ],
    [ "eis_touch_motion", "group__libeis-receiver.html#ga82c99fbe9683cd378bc069bf33f33cf1", null ],
    [ "eis_touch_ref", "group__libeis-receiver.html#ga51f32c6afb4292eed1fc18c9bfcf6196", null ],
    [ "eis_touch_set_user_data", "group__libeis-receiver.html#ga24c67e394c68bd3bb3c541b4ac868a7d", null ],
    [ "eis_touch_unref", "group__libeis-receiver.html#ga6e7ed48330569a1911562bbb0afca009", null ],
    [ "eis_touch_up", "group__libeis-receiver.html#ga701334a8401ed024baad75af2b2baf44", null ],
    [ "eis_unref", "group__libeis.html#gabcbb8dacf8ebc999fe67e11ae546116b", null ]
];